#  Copyright (c) 2022 Mira Geoscience Ltd.
#
#  This file is part of geoapps.
#
#  geoapps is distributed under the terms and conditions of the MIT License
#  (see LICENSE file at the root of this source code package).

from __future__ import annotations

from geoapps.inversion.electricals.induced_polarization.three_dimensions.params import (
    InducedPolarization3DParams,
)

from .direct_current.three_dimensions import DirectCurrent3DParams
